[![Python 3.11](https://img.shields.io/badge/python-3.11-blue.svg)](https://www.python.org/downloads/release/python-3111/)
[![GitHub release (latest by date)](https://img.shields.io/github/v/release/MDU-PHL/bohra)](https://github.com/MDU-PHL/bohra/releases/latest)
[![Conda Downloads](https://img.shields.io/conda/dn/bioconda/bohra)](https://anaconda.org/bioconda/bohra)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![BigCI](https://github.com/MDU-PHL/bohra/actions/workflows/BigCI.yml/badge.svg)](https://github.com/MDU-PHL/bohra/actions/workflows/BigCI.yml)


# Bohra

You can find all documentation for `bohra` [here](https://mdu-phl.github.io/bohra/)

![logo](./docs/images/logo.svg)



For bohra v2 please see our [wiki](https://github.com/MDU-PHL/bohra/wiki)

